==> BootcampDSC-2.0.0.tar.gz: BootcampDSC-2.0.0/BootcampDSC/BootcampDSC.py <==
from PIL import Image
from urllib.request import urlopen

class BootcampDSC:
    def IntroOOPIllustration(self):
        self.gambar = Image.open(urlopen('https://i.ibb.co/mvvXrj5/oop.jpg'))
        return self.gambar

    def ClassIllustration(self):
        self.gambar = Image.open(urlopen('https://i.ibb.co/gzpHLc3/class.jpg'))
        return self.gambar

    def MethodIllustration(self):
        self.gambar = Image.open(urlopen('https://i.ibb.co/hcbd2hd/class-method-attribute.jpg'))
        return self.gambar
    
    def InheritanceIllustration(self):
        self.gambar = Image.open(urlopen('https://i.ibb.co/HYj0Bcr/inherit.jpg'))
        return self.gambar

    def BMIIllustration(self):
        self.gambar = Image.open(urlopen('https://ukurandansatuan.com/wp-content/uploads/2016/07/uds-rumus-menghitung-BMI-400p.jpg'))
        return self.gambar

    def AiMlDlIllustration(self):
        self.gambar = Image.open(urlopen('https://i.ibb.co/K6r11Cz/poop.png'))
        return self.gambar

    def TraditionalApproachIllustration(self):
        self.gambar = Image.open(urlopen('https://i.ibb.co/FzBQzSH/traditional.png'))
        return self.gambar

    def MLApproachIllustration(self):
        self.gambar = Image.open(urlopen('https://i.ibb.co/mhVRYDB/machine.png'))
        return self.gambar

    def MemeML1(self):
        self.gambar = Image.open(urlopen('https://miro.medium.com/max/700/1*Yi64yzIRh5iH3p2Blh8GvA.jpeg'))
        return self.gambar

    def MemeML2(self):
        self.gambar = Image.open(urlopen('https://miro.medium.com/max/2400/1*hx--qD6l1p2ruJSbDSJW6A.jpeg'))
        return self.gambar

    def MemeML3(self):
        self.gambar = Image.open(urlopen('https://i.pinimg.com/originals/fb/76/15/fb7615fc0a7a4298f6b7df219ffac4d1.jpg'))
        return self.gambar

    def ClassificationIllustration(self):
        self.gambar = Image.open(urlopen('https://1zrnlw1lz3wt1zcsci363i2d-wpengine.netdna-ssl.com/wp-content/uploads/2019/06/Classification.png'))
        return self.gambar
    
    def RegressionIllustration(self):
        self.gambar = Image.open(urlopen('https://miro.medium.com/max/3000/0*szXvH1a4ZQytyqhg.png'))
        return self.gambar

    def LinRegIllustration(self):
        self.gambar = Image.open(urlopen('https://miro.medium.com/max/2584/1*Nf2tTTkALYq6RTMQmhjo1A.png'))
        return self.gambar

    def LinRegFormula(self):
        self.gambar = Image.open(urlopen('https://static.packt-cdn.com/products/9781789537123/graphics/78c4af48-3b33-4cbd-bc15-45aeb0f8833e.png'))
        return self.gambar
    
    def LinRegExample(self):
        self.gambar = Image.open(urlopen('https://i.ibb.co/NCf0vvJ/linreg.png'))
        return self.gambar

    def MSEFormula(self):
        self.gambar = Image.open(urlopen('https://www.gstatic.com/education/formulas2/-1/en/mean_squared_error.svg '))
        return self.gambar

    def RMSEFormula(self):
        self.gambar = Image.open(urlopen('https://www.gstatic.com/education/formulas2/-1/en/root_mean_square_deviation.svg'))
        return self.gambar

    def NaiveBayesFormula(self):
        self.gambar = Image.open(urlopen('https://miro.medium.com/max/634/1*1awmAduPuKcaM8aDkSDsUA.png'))
        return self.gambar

    def WeatherBayes1(self):
        self.gambar = Image.open(urlopen('https://i.ibb.co/6mq3HWp/weather.png'))
        return self.gambar

    def WeatherBayes2(self):
        self.gambar = Image.open(urlopen('https://i.ibb.co/j3Hjxn8/weather-2.png'))
        return self.gambar

    def SpamBayes1(self):
        self.gambar = Image.open(urlopen('https://i.ibb.co/ctw6yBd/nb-1.png'))
        return self.gambar

    def SpamBayes2(self):
        self.gambar = Image.open(urlopen('https://i.ibb.co/JnxG4YJ/nb-2.png'))
        return self.gambar

    def SpamBayes3(self):
        self.gambar = Image.open(urlopen('https://i.ibb.co/rMM4Y4h/nb-3.png'))
        return self.gambar

    def SpamBayes4(self):
        self.gambar = Image.open(urlopen('https://i.ibb.co/yVRk4pK/nb-4.png'))
        return self.gambar

    def SpamBayes5(self):
        self.gambar = Image.open(urlopen('https://i.ibb.co/yVRk4pK/nb-4.png'))
        return self.gambar

==> BootcampDSC-2.1.0.tar.gz: BootcampDSC-2.1.0/BootcampDSC/BootcampDSC.py <==
from PIL import Image
from urllib.request import urlopen

class BootcampDSC:
    def IntroOOPIllustration(self):
        self.gambar = Image.open(urlopen('https://i.ibb.co/mvvXrj5/oop.jpg'))
        return self.gambar

    def ClassIllustration(self):
        self.gambar = Image.open(urlopen('https://i.ibb.co/gzpHLc3/class.jpg'))
        return self.gambar

    def MethodIllustration(self):
        self.gambar = Image.open(urlopen('https://i.ibb.co/hcbd2hd/class-method-attribute.jpg'))
        return self.gambar
    
    def InheritanceIllustration(self):
        self.gambar = Image.open(urlopen('https://i.ibb.co/HYj0Bcr/inherit.jpg'))
        return self.gambar

    def BMIIllustration(self):
        self.gambar = Image.open(urlopen('https://ukurandansatuan.com/wp-content/uploads/2016/07/uds-rumus-menghitung-BMI-400p.jpg'))
        return self.gambar

    def AiMlDlIllustration(self):
        self.gambar = Image.open(urlopen('https://i.ibb.co/K6r11Cz/poop.png'))
        return self.gambar

    def TraditionalApproachIllustration(self):
        self.gambar = Image.open(urlopen('https://i.ibb.co/FzBQzSH/traditional.png'))
        return self.gambar

    def MLApproachIllustration(self):
        self.gambar = Image.open(urlopen('https://i.ibb.co/mhVRYDB/machine.png'))
        return self.gambar

    def MemeML1(self):
        self.gambar = Image.open(urlopen('https://miro.medium.com/max/700/1*Yi64yzIRh5iH3p2Blh8GvA.jpeg'))
        return self.gambar

    def MemeML2(self):
        self.gambar = Image.open(urlopen('https://miro.medium.com/max/2400/1*hx--qD6l1p2ruJSbDSJW6A.jpeg'))
        return self.gambar

    def MemeML3(self):
        self.gambar = Image.open(urlopen('https://i.pinimg.com/originals/fb/76/15/fb7615fc0a7a4298f6b7df219ffac4d1.jpg'))
        return self.gambar

    def ClassificationIllustration(self):
        self.gambar = Image.open(urlopen('https://1zrnlw1lz3wt1zcsci363i2d-wpengine.netdna-ssl.com/wp-content/uploads/2019/06/Classification.png'))
        return self.gambar
    
    def RegressionIllustration(self):
        self.gambar = Image.open(urlopen('https://i.ibb.co/3Sqd0Py/regression.png'))
        return self.gambar

    def LinRegIllustration(self):
        self.gambar = Image.open(urlopen('https://i.ibb.co/3dw5BbP/lr.png'))
        return self.gambar

    def LinRegFormula(self):
        self.gambar = Image.open(urlopen('https://static.packt-cdn.com/products/9781789537123/graphics/78c4af48-3b33-4cbd-bc15-45aeb0f8833e.png'))
        return self.gambar
    
    def LinRegExample(self):
        self.gambar = Image.open(urlopen('https://i.ibb.co/NCf0vvJ/linreg.png'))
        return self.gambar

    def MSEFormula(self):
        self.gambar = Image.open(urlopen('https://www.gstatic.com/education/formulas2/-1/en/mean_squared_error.svg '))
        return self.gambar

    def RMSEFormula(self):
        self.gambar = Image.open(urlopen('https://www.gstatic.com/education/formulas2/-1/en/root_mean_square_deviation.svg'))
        return self.gambar

    def NaiveBayesFormula(self):
        self.gambar = Image.open(urlopen('https://i.ibb.co/SvcKz3W/nb.png'))
        return self.gambar

    def WeatherBayes1(self):
        self.gambar = Image.open(urlopen('https://i.ibb.co/6mq3HWp/weather.png'))
        return self.gambar

    def WeatherBayes2(self):
        self.gambar = Image.open(urlopen('https://i.ibb.co/j3Hjxn8/weather-2.png'))
        return self.gambar

    def SpamBayes1(self):
        self.gambar = Image.open(urlopen('https://i.ibb.co/ctw6yBd/nb-1.png'))
        return self.gambar

    def SpamBayes2(self):
        self.gambar = Image.open(urlopen('https://i.ibb.co/JnxG4YJ/nb-2.png'))
        return self.gambar

    def SpamBayes3(self):
        self.gambar = Image.open(urlopen('https://i.ibb.co/rMM4Y4h/nb-3.png'))
        return self.gambar

    def SpamBayes4(self):
        self.gambar = Image.open(urlopen('https://i.ibb.co/yVRk4pK/nb-4.png'))
        return self.gambar

    def SpamBayes5(self):
        self.gambar = Image.open(urlopen('https://i.ibb.co/yVRk4pK/nb-4.png'))
        return self.gambar

    def DataTabularIllustration(self):
        self.gambar = Image.open(urlopen('https://i.ibb.co/5RDRNZC/tabular.png'))
        return self.gambar
